#ifndef NT2_INCLUDE_FUNCTIONS_ALL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ALL_HPP_INCLUDED

#include <nt2/reduction/include/functions/all.hpp>

#endif
